#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class keep_linearized_source_terms_constant(Boolean):
    """
    Enable/disable keeping linearized DPM source terms constant until the next DPM Update.
    """

    fluent_name = "keep-linearized-source-terms-constant?"

