#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class linear_growth_of_dpm_source_terms(Boolean):
    """
    Enable/disable the linear growth of DPM source terms every DPM iteration.
    """

    fluent_name = "linear-growth-of-dpm-source-terms?"

