#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class zero_nodal_velocities_on_walls(Boolean):
    """
    Enable/disable setting the nodal velocity on all walls to zero.
    """

    fluent_name = "zero-nodal-velocities-on-walls?"

