#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class tracking_statistics_format(Integer):
    """
    Control the format of the one-line tracking statistics printed after every DPM tracking pass.
    """

    fluent_name = "tracking-statistics-format"

